# remirepo spec file for php-pecl-vld
#
# Copyright (c) 2013-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package       php-pecl-vld
%endif

%global gh_commit   8146d47ed5883c0b7cb9c5ce980892ce286cd916
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    derickr
%global gh_project  vld
#global gh_date     20180814
%global pecl_name vld
%global with_zts  0%{!?_without_zts:%{?__ztsphp:1}}
%if "%{php_version}" < "5.6"
%global ini_name  %{pecl_name}.ini
%else
%global ini_name  40-%{pecl_name}.ini
%endif

Summary:        Dump the internal representation of PHP scripts
Name:           %{?sub_prefix}php-pecl-%{pecl_name}
Version:        0.17.0
%if 0%{?gh_date:1}
Release:        0.16.%{gh_date}.%{gh_short}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{pecl_name}-%{version}-%{gh_short}.tar.gz
%else
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz
%endif
License:        PHP
URL:            https://pecl.php.net/package/%{pecl_name}

BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel > 7
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%endif

%if "%{?vendor}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.2"
Obsoletes:     php72u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php72w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.3"
Obsoletes:     php73-pecl-%{pecl_name}  <= %{version}
Obsoletes:     php73w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:     php74-pecl-%{pecl_name}  <= %{version}
Obsoletes:     php74w-pecl-%{pecl_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter private shared
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
The Vulcan Logic Disassembler hooks into the Zend Engine and
dumps all the opcodes (execution units) of a script.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
%if 0%{?gh_date:1}
mv %{gh_project}-%{gh_commit} NTS
%{__php} -r '
  $pkg = simplexml_load_file("NTS/package.xml");
  $pkg->date = substr("%{gh_date}",0,4)."-".substr("%{gh_date}",4,2)."-".substr("%{gh_date}",6,2);
  $pkg->version->release = "%{version}dev";
  $pkg->stability->release = "devel";
  $pkg->asXML("package.xml");
'
%else
mv %{pecl_name}-%{version} NTS
%endif

%{?_licensedir:sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml}

: Fix version
sed -e 's/"0.16.0"/"%{version}"/' -i NTS/vld.c

: Check version
if ! grep -q '"%{version}%{?gh_date:-dev}"' NTS/vld.c; then
   : Error: Upstream extension version, expecting %{version}%{?gh_date:-dev}%{?prever:-%{prever}}.
   exit 1
fi


%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

;vld.active=0
;vld.skip_prepend=0
;vld.skip_append=0
;vld.execute=1
;vld.verbosity=1
;vld.format=0
;vld.col_sep="	"
;vld.save_dir="/tmp"
;vld.save_paths=0
;vld.dump_paths=1
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd NTS
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done
%{!?_licensedir:install -Dpm 644 LICENSE %{buildroot}%{pecl_docdir}/%{pecl_name}/LICENSE}


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
# Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=NTS/modules/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_zts}
# Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=ZTS/modules/%{pecl_name}.so \
    --modules | grep %{pecl_name}
%endif


%files
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Jan 14 2020 Remi Collet <remi@remirepo.net> - 0.17.0-1
- update to 0.17.0

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.16.0-3
- rebuild for 7.4.0RC1

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 0.16.0-2
- rebuild

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 0.16.0-1
- update to 0.16.0

* Tue Dec  4 2018 Remi Collet <remi@remirepo.net> - 0.15.0-1
- update to 0.15.0

* Fri Aug 24 2018 Remi Collet <remi@remirepo.net> - 0.15.0-0.14.20180814.8146d47
- refresh

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.15.0-0.13.20180514.1719df5
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.15.0-0.12.20180514.1719df5
- rebuild for 7.3.0alpha4 new ABI

* Mon Jul  2 2018 Remi Collet <remi@remirepo.net> - 0.15.0-0.11.20180514.1719df5
- update to 0.15.0-dev for PHP 7.3

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.14.0-2
- rebuild for PHP 7.2.0beta1 new API

* Mon Dec 19 2016 Remi Collet <remi@fedoraproject.org> - 0.14.0-1
- Update to 0.14.0

* Tue Mar  8 2016 Remi Collet <remi@fedoraproject.org> - 0.13.0-2
- adapt for F24
- fix license management

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 0.13.0-1.1
- Fedora 21 SCL mass rebuild

* Fri Nov 14 2014 Remi Collet <remi@fedoraproject.org> - 0.13.0-1
- Update to 0.13.0 (beta)

* Tue Aug 26 2014 Remi Collet <rcollet@redhat.com> - 0.12.0-6
- improve SCL build

* Thu Jun 26 2014 Remi Collet <remi@fedoraproject.org> - 0.12.0-5
- more upstream patches for PHP 5.6

* Thu Apr 17 2014 Remi Collet <remi@fedoraproject.org> - 0.12.0-4
- add numerical prefix to extension configuration file (php 5.6)

* Mon Mar 24 2014 Remi Collet <remi@fedoraproject.org> - 0.12.0-3
- allow SCL build

* Sun Mar 16 2014 Remi Collet <remi@fedoraproject.org> - 0.12.0-2
- install doc in pecl_docdir
- add missing License file (from github repo)
- apply upstream patch for PHP 5.6

* Wed Sep 25 2013 Remi Collet <remi@fedoraproject.org> - 0.12.0-1
- initial package
